pub struct ImportProjectionRecordV3 {
pub record: ImportProjectionRecord,
pub semantics: Option<ExportRecordSemanticsV3>,
}Expand description
A single import record enriched with export-time semantics for kernel compilation.
Fields
record: ImportProjectionRecordsemantics: Option<ExportRecordSemanticsV3>Trait Implementations
Sourceimpl Clone for ImportProjectionRecordV3
impl Clone for ImportProjectionRecordV3
Sourcefn clone(&self) -> ImportProjectionRecordV3
fn clone(&self) -> ImportProjectionRecordV3
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ImportProjectionRecordV3
impl Debug for ImportProjectionRecordV3
Sourceimpl<'de> Deserialize<'de> for ImportProjectionRecordV3
impl<'de> Deserialize<'de> for ImportProjectionRecordV3
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ImportProjectionRecordV3
impl JsonSchema for ImportProjectionRecordV3
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ImportProjectionRecordV3
impl RefUnwindSafe for ImportProjectionRecordV3
impl Send for ImportProjectionRecordV3
impl Sync for ImportProjectionRecordV3
impl Unpin for ImportProjectionRecordV3
impl UnsafeUnpin for ImportProjectionRecordV3
impl UnwindSafe for ImportProjectionRecordV3